class FailedToFindASolutionError(Exception):
    ...


class SolverNotSupportedError(Exception):
    ...


class InvalidWordleBotFileError(Exception):
    ...
